@@ -378,7 +378,6 @@ def decipher_primary(primary):
     stmts = []
     ada_string = ''
     local_decl = []
-
     if primary.kind == 'primaryId':
         stmts, ada_string, local_decl = decipher_primary_id(primary.primaryId)
     elif primary.kind == 'enumeratedValue':
@@ -389,10 +388,10 @@ def decipher_primary(primary):
     elif primary.kind in ('numericalValue', 'booleanValue'):
         ada_string = primary.primaryId[0]
     elif primary.kind == 'sequence':
-        stmts, ada_string, local_decl = decipherSequence(
+        stmts, ada_string, local_decl = decipher_sequence(
                 primary.sequence, primary.primType)
     elif primary.kind == 'sequenceOf':
-        stmts, ada_string, local_decl = decipherSequenceOf(
+        stmts, ada_string, local_decl = decipher_sequence_of(
                 primary.sequenceOf, primary.primType)
     elif primary.kind == 'choiceItem':
         stmts, ada_string, local_decl = decipher_choice(
@@ -403,7 +402,7 @@ def decipher_primary(primary):
     elif primary.kind == 'stringLiteral':
         pass
     elif primary.kind == 'ifThenElse':
-        stmts, ada_string, local_decl = decipherIfThenElse(
+        stmts, ada_string, local_decl = decipher_if_then_else(
                 primary.ifThenElse, primary.primType)
     elif primary.kind == 'expression':
         stmts, ada_string, local_decl = decipher_expression(primary.expr)
@@ -414,13 +413,14 @@ def decipher_primary(primary):
     return stmts, ada_string, local_decl
 
 
-def decipherIfThenElse(ifThenElse, resType):
+def decipher_if_then_else(ifThenElse, resType):
     ''' Return string and statements for ternary operator '''
     stmts = []
     # FIXME: resType may be wrong if declaration embedded in SEQUENCE
     # TODO: find a non-conflicing naming convention for tmp variable
     local_decl = ['tmp{idx} : asn1Scc{resType};'.format(
-        idx=ifThenElse['tmpVar'], resType=resType['ReferencedTypeName'])]
+        idx=ifThenElse['tmpVar'], resType=resType.get('ReferencedTypeName') or
+        'ERROR!')]
     if_stmts, ifString, ifLocal = decipher_expression(ifThenElse['if'])
     then_stmts, thenString, thenLocal = decipher_expression(ifThenElse['then'])
     else_stmts, elseString, elseLocal = decipher_expression(ifThenElse['else'])
@@ -442,7 +442,7 @@ def decipherIfThenElse(ifThenElse, resType):
     return stmts, ada_string, local_decl
 
 
-def decipherSequence(seq, seqType):
+def decipher_sequence(seq, seqType):
     ''' Return Ada string for an ASN.1 SEQUENCE '''
     #print '[DEBUG] Sequence:', seq, seqType
     ada_string = 'asn1Scc{seqType}\'('.format(
@@ -467,7 +467,7 @@ def decipherSequence(seq, seqType):
     return stmts, ada_string, local_decl
 
 
-def decipherSequenceOf(seqof, seqofType):
+def decipher_sequence_of(seqof, seqofType):
     ''' Return Ada string for an ASN.1 SEQUENCE OF '''
     stmts = []
     local_decl = []
@@ -506,9 +506,9 @@ def decipher_choice(choice, choiceType):
     if choice['value'].exprType['Kind'] == 'UnknownType':
         # To handle non-explicit type definition (e.g CHOICE { a SEQUENCE...)
         choice['value'].exprType = {'Kind': 'ReferenceType',
-        'ReferencedTypeName': '{baseType}_{choiceValue}'.format(
-            baseType=choiceType.get('ReferencedTypeName'),
-            choiceValue=choice['choice'])}
+                'ReferencedTypeName': '{baseType}_{choiceValue}'.format(
+                    baseType=choiceType.get('ReferencedTypeName'),
+                    choiceValue=choice['choice'])}
 
     stmts, choiceStr, local_decl = decipher_expression(choice['value'])
 
