@@ -58,7 +58,7 @@ from PySide.QtGui import(QGraphicsTextItem, QGraphicsPathItem,
         QGraphicsItemGroup, QCompleter, QGraphicsProxyWidget, QListWidget,
         QListWidgetItem, QTextCursor, QSyntaxHighlighter, QTextCharFormat,
         QFont, QPolygon, QPen, QColor, QMenu, QFileDialog, QImage, QPainter,
-        QLineEdit, QBrush)
+        QLineEdit, QBrush, QTextBlockFormat)
 
 from PySide.QtUiTools import QUiLoader
 
@@ -89,7 +89,7 @@ class Completer(QGraphicsProxyWidget):
         self.c.setCaseSensitivity(Qt.CaseInsensitive)
         self.parent = parent
 
-    def setCompletionPrefix(self, completionPrefix):
+    def set_completion_prefix(self, completionPrefix):
         '''
         Set the current completion prefix (user-entered text)
         and set the corresponding list of words in the popup widget
@@ -101,7 +101,7 @@ class Completer(QGraphicsProxyWidget):
         for i in xrange(self.c.completionCount()):
             self.c.setCurrentRow(i)
             self.widget().addItem(self.c.currentCompletion())
-        self.resize(self.widget().sizeHintForColumn(0)+40, 70)
+        self.resize(self.widget().sizeHintForColumn(0) + 40, 70)
         return self.c.completionCount()
 
     def keyPressEvent(self, e):
@@ -182,30 +182,45 @@ class EditableText(QGraphicsTextItem):
                 | Qt.LinksAccessibleByKeyboard)
         self.completerHasFocus = False
         self.editing = False
-        self.tryResize()
+        self.try_resize()
         self.highlighter = Highlighter(self.document())
-        self.computePos()
+        self.set_textbox_position()
+        self.set_text_alignment()
 
     def __str__(self):
         ''' Print the text inside the symbol '''
         return self.toPlainText()
 
-    def computePos(self):
-        ''' Compute the text position (in the center of its parent) '''
+    def set_text_alignment(self):
+        ''' Apply the required text alignment within the text box '''
+        alignment = self.parentItem().text_alignment
+        self.setTextWidth(self.boundingRect().width())
+        fmt = QTextBlockFormat()
+        fmt.setAlignment(alignment)
+        cursor = self.textCursor()
+        cursor.select(QTextCursor.Document)
+        cursor.mergeBlockFormat(fmt)
+        cursor.clearSelection()
+        self.setTextCursor(cursor)
+
+    def set_textbox_position(self):
+        ''' Compute the textbox position '''
         parentRect = self.parentItem().boundingRect()
         rect = self.boundingRect()
-        if not hasattr(self.parentItem(), 'textPosition'):
-            self.setPos(parentRect.center()-rect.center())
-        else:
-            # TODO: support additional text positions
+        # Use parent symbol alignment requirement
+        # Can be extended to support more combinations..
+        alignment = self.parentItem().textbox_alignment
+        if alignment & Qt.AlignCenter:
+            self.setPos(parentRect.center() - rect.center())
+        elif (alignment & Qt.AlignTop) and (alignment & Qt.AlignLeft):
             self.setPos(0, 0)
 
     def paint(self, painter, _, __):
         ''' Place the text properly in the middle of the parent symbol '''
-        self.computePos()
+        self.set_textbox_position()
         super(EditableText, self).paint(painter, _, __)
 
-    def tryResize(self):
+    def try_resize(self):
         '''
             If needed, request a resizing of the parent item
             (when text size expands)
@@ -218,7 +233,7 @@ class EditableText(QGraphicsTextItem):
         self.parentItem().resizeItem(parentRect)
 
     @Slot(QListWidgetItem)
-    def completionSelected(self, item):
+    def completion_selected(self, item):
         '''
             Slot connected to the autocompletion popup,
             invoked when selection is made
@@ -233,12 +248,12 @@ class EditableText(QGraphicsTextItem):
         self.completerHasFocus = False
         self.completer.hide()
 
-    def keyPressEvent(self, e):
+    def keyPressEvent(self, event):
         '''
             Activate the autocompletion window if relevant
         '''
-        super(EditableText, self).keyPressEvent(e)
-        self.tryResize()
+        super(EditableText, self).keyPressEvent(event)
+        self.try_resize()
         tc = self.textCursor()
         tc.select(QTextCursor.WordUnderCursor)
         self.completionPrefix = tc.selectedText()
@@ -246,12 +261,12 @@ class EditableText(QGraphicsTextItem):
                 self.completer):
             self.completer = Completer(self)
             self.completer.widget().itemActivated.connect(
-                    self.completionSelected)
+                    self.completion_selected)
         if self.completer:
-            completionCount = self.completer.setCompletionPrefix(
+            completionCount = self.completer.set_completion_prefix(
                     self.completionPrefix)
             if completionCount > 0 and (len(self.completionPrefix) > 1 or
-                    e.key() == Qt.Key_F8):
+                    event.key() == Qt.Key_F8):
                 # Computing the position of the completer
                 # No direct Qt function for that.. doing it the hard way
                 pos = self.textCursor().positionInBlock()
@@ -273,7 +288,7 @@ class EditableText(QGraphicsTextItem):
                 self.completer.hide()
                 self.setFocus()
             self.completerHasFocus = False
-            if self.completer.isVisible() and e.key() == Qt.Key_Down:
+            if self.completer.isVisible() and event.key() == Qt.Key_Down:
                 self.completerHasFocus = True
                 self.completer.setFocusProxy(None)
                 self.completer.widget().setFocus()
@@ -310,10 +325,13 @@ class EditableText(QGraphicsTextItem):
             # Call syntax checker from item containing the text (if any)
             self.parentItem().checkSyntax()
         self.setSelected(False)
+        self.set_text_alignment()
         super(EditableText, self).focusOutEvent(event)
 
     def focusInEvent(self, event):
         ''' When user starts editing text, save previous state for Undo '''
+        # Set width to auto-expand, and disables alignment, while editing:
+        self.setTextWidth(-1)
         if self.completer:
             self.completer.resize(0, 0)
         if not self.editing:
@@ -338,8 +356,9 @@ class EditableText(QGraphicsTextItem):
             TODO: remove from here, put in SDL symbols
         '''
         if self.hyperlink:
-            return "/* CIF Keep Specific Geode HyperLink '{hlink}' */\n".format(
-                    hlink=self.hyperlink)
+            return(
+                "/* CIF Keep Specific Geode HyperLink '{hlink}' */\n".format(
+                    hlink=self.hyperlink))
         else:
             return ''
 
@@ -379,9 +398,11 @@ class Connection(QGraphicsPathItem):
                 self.child, (HorizontalSymbol, Comment)):
             self.startPoint = self.parentItem().connectionPoint
         elif isinstance(self.child, Comment):
-            self.startPoint = QPointF(parentRect.width(), parentRect.height()/2)
+            self.startPoint = QPointF(
+                    parentRect.width(), parentRect.height() / 2)
         else:
-            self.startPoint = QPointF(parentRect.width()/2, parentRect.height())
+            self.startPoint = QPointF(
+                    parentRect.width() / 2, parentRect.height())
         # Defined connection end point
         if self.childIsAConnectionPoint:
             connectionPointScene = self.child.mapToScene(
@@ -392,11 +413,13 @@ class Connection(QGraphicsPathItem):
         elif isinstance(self.child, Comment):
             if self.child.onTheRight:
                 self.endPoint = QPointF(self.child.x(),
-                        self.child.y()+self.child.boundingRect().height()/2)
+                        self.child.y() +
+                        self.child.boundingRect().height() / 2)
             else:
                 self.endPoint = QPointF(self.child.x() +
                         self.child.boundingRect().width(),
-                        self.child.y()+self.child.boundingRect().height()/2)
+                        self.child.y() +
+                        self.child.boundingRect().height() / 2)
         else:
             self.endPoint = QPointF()
             self.endPoint.setY(self.child.pos().y())
@@ -406,9 +429,9 @@ class Connection(QGraphicsPathItem):
                 self.child, Comment):
             if isinstance(self.child, HorizontalSymbol):
                 self.endPoint.setX(self.child.pos().x() +
-                        self.child.boundingRect().width()/2)
-                arrowPath.lineTo(self.startPoint.x(), self.startPoint.y()+10)
-                arrowPath.lineTo(self.endPoint.x(), self.startPoint.y()+10)
+                        self.child.boundingRect().width() / 2)
+                arrowPath.lineTo(self.startPoint.x(), self.startPoint.y() + 10)
+                arrowPath.lineTo(self.endPoint.x(), self.startPoint.y() + 10)
             else:
                 self.endPoint.setX(self.startPoint.x())
         elif isinstance(self.child, Comment):
@@ -424,14 +447,14 @@ class Connection(QGraphicsPathItem):
             arrowPath.lineTo(goToPoint, self.endPoint.y())
             arrowPath.lineTo(self.endPoint.x(), self.endPoint.y())
         else:
-            arrowPath.lineTo(self.startPoint.x(), self.endPoint.y()-10)
-            arrowPath.lineTo(self.endPoint.x(), self.endPoint.y()-10)
+            arrowPath.lineTo(self.startPoint.x(), self.endPoint.y() - 10)
+            arrowPath.lineTo(self.endPoint.x(), self.endPoint.y() - 10)
         arrowPath.lineTo(self.endPoint)
         # If required draw an arrow head (e.g. in SDL NEXTSTATE and GOTO)
         if hasattr(self.child, 'arrowHead'):
-            arrowPath.lineTo(self.endPoint.x()-5, self.endPoint.y()-5)
+            arrowPath.lineTo(self.endPoint.x() - 5, self.endPoint.y() - 5)
             arrowPath.moveTo(self.endPoint)
-            arrowPath.lineTo(self.endPoint.x()+5, self.endPoint.y()-5)
+            arrowPath.lineTo(self.endPoint.x() + 5, self.endPoint.y() - 5)
         self.setPath(arrowPath)
 
 # Notes on performance: boundingRect() is called by Qt to know if the item
@@ -487,13 +510,17 @@ class Symbol(QGraphicsPolygonItem):
         self.branchEntryPoint = None
         # Terminal symbol can be used to identify last items of a branch
         self.terminalSymbol = False
+        # default textbox alignment: centered in the symbol
+        # can differ on specific symbols (e.g. TextArea or label)
+        self.textbox_alignment = Qt.AlignCenter
+        # and default text alignment within a textbox
+        self.text_alignment = Qt.AlignLeft
         self.setFlags(
                 QGraphicsItem.ItemIsMovable
                 | QGraphicsItem.ItemIsSelectable
                 | QGraphicsItem.ItemSendsGeometryChanges)
 #                | QGraphicsItem.ItemSendsScenePositionChanges)
 
-
     def itemChange(self, change, value):
         '''
             Function called by Qt when anything happens to the symbol
@@ -662,7 +689,8 @@ class Symbol(QGraphicsPolygonItem):
                     filename += '.png'
                 oldBrush = self.scene().backgroundBrush()
                 self.scene().setBackgroundBrush(QBrush())
-                completeRect = self.childrenBoundingRect() | self.boundingRect()
+                completeRect = (self.childrenBoundingRect() |
+                                self.boundingRect())
                 # Add some margin for the antialiasing (5 pixels on each side)
                 completeRect.adjust(-5, -5, 5, 5)
                 rect = self.mapRectToScene(completeRect)
@@ -685,12 +713,12 @@ class Symbol(QGraphicsPolygonItem):
                     self.hyperlink_dialog.show()
 
     def childSymbols(self):
-        ''' Return the list of child symbols, excluding text and connections '''
+        ''' Return the list of child symbols, excluding text/connections '''
         return [item for item in self.childItems() if isinstance(item, Symbol)]
 
     def resizeItem(self, rect):
         ''' resize item, e.g. when editing text - move children accordingly '''
-        deltaX = (self.boundingRect().width() - rect.width())/2
+        deltaX = (self.boundingRect().width() - rect.width()) / 2
         deltaY = self.boundingRect().height() - rect.height()
         self.prepareGeometryChange()
         polygon = self.computePolygon(rect.width(), rect.height())
@@ -718,7 +746,8 @@ class Symbol(QGraphicsPolygonItem):
         eventPos = event.pos()
         rect = self.boundingRect()
         self.height = rect.height()
-        if eventPos.x() > rect.width()-10 and eventPos.y() > rect.height()-10:
+        if(eventPos.x() > rect.width() - 10 and
+                eventPos.y() > rect.height() - 10):
             self.mode = 'Resize'
             self.oldRect = self.boundingRect()
         else:
@@ -732,8 +761,9 @@ class Symbol(QGraphicsPolygonItem):
             # Minimum size is the size of the text inside the symbol
             if self.text:
                 newY = max(event.pos().y(),
-                        self.text.boundingRect().height()+10)
-                newX = max(event.pos().x(), self.text.boundingRect().width()+30)
+                        self.text.boundingRect().height() + 10)
+                newX = max(event.pos().x(),
+                           self.text.boundingRect().width() + 30)
             else:
                 newY = max(event.pos().y(), 15)
                 newX = max(event.pos().x(), 30)
@@ -900,7 +930,7 @@ class Comment(Symbol):
             self.setY(y)
         else:
             self.setY((parent.boundingRect().height() -
-                self.boundingRect().height())/2)
+                self.boundingRect().height()) / 2)
         self.connection = self.connectToParent()
         if self.x() < parent.boundingRect().width() + 5:
             self.onTheRight = False
@@ -947,8 +977,8 @@ class Comment(Symbol):
             painter.drawLines([QPoint(x, y), QPoint(w, y),
                                QPoint(w, y), QPoint(w, h),
                                QPoint(w, h), QPoint(x, h)])
-        # Call parent paint function to have the drawing of the selection border
-        # (when item is selected)
+        # Call parent paint function to have the drawing of the selection box
+        # (when item is selected it will draw a dashed line around it)
         super(Comment, self).paint(painter, _, __)
 
     def mouseMoveEvent(self, event):
@@ -1028,7 +1058,7 @@ class HorizontalSymbol(Symbol):
             groupW = group.boundingRect().width()
             self.scene().destroyItemGroup(group)
             for s in siblings:
-                sX = s.x() - (self.boundingRect().width())/2 - 10
+                sX = s.x() - (self.boundingRect().width()) / 2 - 10
                 sOldPos = s.pos()
                 s.setX(sX)
                 undoCmd = MoveSymbol(s, sOldPos, s.pos())
@@ -1039,8 +1069,9 @@ class HorizontalSymbol(Symbol):
             else:
                 # Verical alignment (x-axis):
                 posX = (parent.boundingRect().width() -
-                        self.boundingRect().width())/2
-            posY = parent.boundingRect().height()+self.minDistanceToSymbolAbove
+                        self.boundingRect().width()) / 2
+            posY = (parent.boundingRect().height() +
+                    self.minDistanceToSymbolAbove)
             self.setPos(posX, posY)
         else:
             self.setPos(x, y)
@@ -1222,7 +1253,7 @@ class VerticalSymbol(Symbol):
         # 'or self.parent' because of pyside/qt bug
         parent = self.parentItem() or self.parent
         x = (self.boundingRect().width() -
-                parent.boundingRect().width())/2
+             parent.boundingRect().width()) / 2
         # In case of collision with parent item, move down
         for item in self.collidingItems():
             if hasattr(self.parentItem(), 'connectionPoint'):
