@@ -784,15 +784,20 @@ class sdlScc_AST:
             # check for type compatibility with the other operand
             rightIsRaw = (expr.right.kind == 'primary' and
                     expr.right.exprType['Kind'] in
-                    ('UnknownType', 'IntegerType', 'RealType', 'BooleanType'))
+                    ('UnknownType', 'IntegerType', 'RealType', 'BooleanType')
+                    and len(expr.right.var.primaryId) == 1)
             leftIsRaw = (expr.left.kind == 'primary' and
                     expr.left.exprType['Kind'] in
-                    ('UnknownType', 'IntegerType', 'RealType', 'BooleanType'))
+                    ('UnknownType', 'IntegerType', 'RealType', 'BooleanType')
+                    and len(expr.left.var.primaryId) == 1)
 
             if (rightIsRaw and expr.right.exprType['Kind'] in
                     ('IntegerType', 'RealType')):
                 expr.right.var.kind = 'numericalValue'
 
+            if expr.left.kind == 'primary':
+                print expr.left, expr.left.var.kind
+
             if (leftIsRaw and expr.left.exprType['Kind'] in
                     ('IntegerType', 'RealType')):
                 expr.left.var.kind = 'numericalValue'
@@ -1680,10 +1685,11 @@ def parseProcessDefinition(fileName=None, string=None):
                 warnings.append([w] if type(w) is not list else w)
         # Post-parsing: additional semantic checks
         # check that all NEXTSTATEs have a correspondingly defined STATE
+        # (except the '-' state, which means "stay in the same state')
         for ns in [t.inputString.lower() for t in backend.process.terminators
                 if t.kind == 'next_state']:
             if not ns in [s.lower() for s in
-                    backend.process.mapping.viewkeys()]:
+                    backend.process.mapping.viewkeys()] + ['-']:
                 errors.append(['State definition missing: ' + ns.upper()])
         # TODO: do the same with JOIN/LABEL
         return backend.process, warnings, errors
