@@ -185,6 +185,7 @@ class Decision(VerticalSymbol):
         self.terminalSymbol = False
         self.commonName = 'decision'
         self.parser = ogParser
+        self.text_alignment = Qt.AlignHCenter
         if ast.comment:
             Comment(parent=self, ast=ast.comment)
 
@@ -442,7 +443,7 @@ class Label(VerticalSymbol):
                 y=coord_y, hyperlink=ast.hyperlink)
         self.setPen(QColor(0, 0, 0, 0))
         self.terminalSymbol = False
-        self.textPosition = (0, 0)
+        self.textbox_alignment = Qt.AlignLeft | Qt.AlignTop
         self.commonName = 'label'
         self.parser = ogParser
 
@@ -657,7 +658,8 @@ class TextSymbol(HorizontalSymbol):
         self.setPos(coord_x, coord_y)
         # Disable hyperlinks for Text symbols
         self._no_hyperlink = True
-        self.textPosition = (0, 0)
+        # Text is not centered in the box - change default alignment:
+        self.textbox_alignment = Qt.AlignLeft | Qt.AlignTop
         self.commonName = 'text_area'
         self.parser = ogParser
 
